==> brmo-stufbg204-1.6.2-sources.jar: nl/egem/stuf/sector/bg/_0204/OBWVraag.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * Overig bouwwerk binnen vraagbericht
 * 
 * <p>Java class for OBW-vraag complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OBW-vraag">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}OBW-fund">
 *       &lt;sequence>
 *         &lt;element name="OBWADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" minOccurs="0"/>
 *         &lt;element name="OBWKDO" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="OBWBSG" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OBW-vraag", propOrder = {
    "obwadr",
    "obwkdo",
    "obwbsg"
})
public class OBWVraag
    extends OBWFund
{

    @XmlElementRef(name = "OBWADR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelFund> obwadr;
    @XmlElementRef(name = "OBWKDO", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<OBWVraag.OBWKDO> obwkdo;
    @XmlElementRef(name = "OBWBSG", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<OBWVraag.OBWBSG> obwbsg;

    /**
     * Gets the value of the obwadr property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public JAXBElement<ADRRelFund> getOBWADR() {
        return obwadr;
    }

    /**
     * Sets the value of the obwadr property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public void setOBWADR(JAXBElement<ADRRelFund> value) {
        this.obwadr = value;
    }

    /**
     * Gets the value of the obwkdo property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link OBWVraag.OBWKDO }{@code >}
     *     
     */
    public JAXBElement<OBWVraag.OBWKDO> getOBWKDO() {
        return obwkdo;
    }

    /**
     * Sets the value of the obwkdo property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link OBWVraag.OBWKDO }{@code >}
     *     
     */
    public void setOBWKDO(JAXBElement<OBWVraag.OBWKDO> value) {
        this.obwkdo = value;
    }

    /**
     * Gets the value of the obwbsg property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link OBWVraag.OBWBSG }{@code >}
     *     
     */
    public JAXBElement<OBWVraag.OBWBSG> getOBWBSG() {
        return obwbsg;
    }

    /**
     * Sets the value of the obwbsg property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link OBWVraag.OBWBSG }{@code >}
     *     
     */
    public void setOBWBSG(JAXBElement<OBWVraag.OBWBSG> value) {
        this.obwbsg = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "bsg"
    })
    public static class OBWBSG
        extends Relatie
    {

        @XmlElement(name = "BSG", required = true, nillable = true)
        protected BSGFund bsg;

        /**
         * Gets the value of the bsg property.
         * 
         * @return
         *     possible object is
         *     {@link BSGFund }
         *     
         */
        public BSGFund getBSG() {
            return bsg;
        }

        /**
         * Sets the value of the bsg property.
         * 
         * @param value
         *     allowed object is
         *     {@link BSGFund }
         *     
         */
        public void setBSG(BSGFund value) {
            this.bsg = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "kdo"
    })
    public static class OBWKDO
        extends Relatie
    {

        @XmlElement(name = "KDO", required = true, nillable = true)
        protected KDOKennisgeving kdo;

        /**
         * Gets the value of the kdo property.
         * 
         * @return
         *     possible object is
         *     {@link KDOKennisgeving }
         *     
         */
        public KDOKennisgeving getKDO() {
            return kdo;
        }

        /**
         * Sets the value of the kdo property.
         * 
         * @param value
         *     allowed object is
         *     {@link KDOKennisgeving }
         *     
         */
        public void setKDO(KDOKennisgeving value) {
            this.kdo = value;
        }

    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/OBWVraag.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * Overig bouwwerk binnen vraagbericht
 * 
 * <p>Java class for OBW-vraag complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OBW-vraag"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}OBW-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="OBWADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" minOccurs="0"/&gt;
 *         &lt;element name="OBWKDO" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="OBWBSG" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OBW-vraag", propOrder = {
    "obwadr",
    "obwkdo",
    "obwbsg"
})
public class OBWVraag
    extends OBWFund
{

    @XmlElementRef(name = "OBWADR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelFund> obwadr;
    @XmlElementRef(name = "OBWKDO", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<OBWVraag.OBWKDO> obwkdo;
    @XmlElementRef(name = "OBWBSG", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<OBWVraag.OBWBSG> obwbsg;

    /**
     * Gets the value of the obwadr property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public JAXBElement<ADRRelFund> getOBWADR() {
        return obwadr;
    }

    /**
     * Sets the value of the obwadr property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public void setOBWADR(JAXBElement<ADRRelFund> value) {
        this.obwadr = value;
    }

    /**
     * Gets the value of the obwkdo property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link OBWVraag.OBWKDO }{@code >}
     *     
     */
    public JAXBElement<OBWVraag.OBWKDO> getOBWKDO() {
        return obwkdo;
    }

    /**
     * Sets the value of the obwkdo property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link OBWVraag.OBWKDO }{@code >}
     *     
     */
    public void setOBWKDO(JAXBElement<OBWVraag.OBWKDO> value) {
        this.obwkdo = value;
    }

    /**
     * Gets the value of the obwbsg property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link OBWVraag.OBWBSG }{@code >}
     *     
     */
    public JAXBElement<OBWVraag.OBWBSG> getOBWBSG() {
        return obwbsg;
    }

    /**
     * Sets the value of the obwbsg property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link OBWVraag.OBWBSG }{@code >}
     *     
     */
    public void setOBWBSG(JAXBElement<OBWVraag.OBWBSG> value) {
        this.obwbsg = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "bsg"
    })
    public static class OBWBSG
        extends Relatie
    {

        @XmlElement(name = "BSG", required = true, nillable = true)
        protected BSGFund bsg;

        /**
         * Gets the value of the bsg property.
         * 
         * @return
         *     possible object is
         *     {@link BSGFund }
         *     
         */
        public BSGFund getBSG() {
            return bsg;
        }

        /**
         * Sets the value of the bsg property.
         * 
         * @param value
         *     allowed object is
         *     {@link BSGFund }
         *     
         */
        public void setBSG(BSGFund value) {
            this.bsg = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "kdo"
    })
    public static class OBWKDO
        extends Relatie
    {

        @XmlElement(name = "KDO", required = true, nillable = true)
        protected KDOKennisgeving kdo;

        /**
         * Gets the value of the kdo property.
         * 
         * @return
         *     possible object is
         *     {@link KDOKennisgeving }
         *     
         */
        public KDOKennisgeving getKDO() {
            return kdo;
        }

        /**
         * Sets the value of the kdo property.
         * 
         * @param value
         *     allowed object is
         *     {@link KDOKennisgeving }
         *     
         */
        public void setKDO(KDOKennisgeving value) {
            this.kdo = value;
        }

    }

}
